Features
========

-  questions
-  pretty much configurable
-  load from config file
-  you can make your own presets
-  can be used interactively *(docs needed)*
-  can be used as a library *(docs needed)*

